==> libreoffice_6.4.2.orig.tar.xz: libreoffice-6.4.2/svx/source/unodialogs/textconversiondlgs/services.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "chinese_translation_unodialog.hxx"
#include <cppuhelper/implementationentry.hxx>

static const struct ::cppu::ImplementationEntry g_entries_unodialogs_chinesetranslation[] =
{
    {
          ::textconversiondlgs::ChineseTranslation_UnoDialog::create
        , ::textconversiondlgs::ChineseTranslation_UnoDialog::getImplementationName_Static
        , ::textconversiondlgs::ChineseTranslation_UnoDialog::getSupportedServiceNames_Static
        , ::cppu::createSingleComponentFactory
        , nullptr
        , 0
    }
    ,{ nullptr, nullptr, nullptr, nullptr, nullptr, 0 }
};

// component exports
extern "C"
{

SAL_DLLPUBLIC_EXPORT void * textconversiondlgs_component_getFactory(
    const sal_Char * pImplName, void * pServiceManager, void * pRegistryKey )
{
    return ::cppu::component_getFactoryHelper(
        pImplName, pServiceManager, pRegistryKey , g_entries_unodialogs_chinesetranslation );
}
}


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_7.0.4.orig.tar.xz: libreoffice-7.0.4.2/svx/source/unodialogs/textconversiondlgs/services.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "chinese_translation_unodialog.hxx"
#include <cppuhelper/implementationentry.hxx>

static const struct ::cppu::ImplementationEntry g_entries_unodialogs_chinesetranslation[] =
{
    {
          ::textconversiondlgs::ChineseTranslation_UnoDialog::create
        , ::textconversiondlgs::ChineseTranslation_UnoDialog::getImplementationName_Static
        , ::textconversiondlgs::ChineseTranslation_UnoDialog::getSupportedServiceNames_Static
        , ::cppu::createSingleComponentFactory
        , nullptr
        , 0
    }
    ,{ nullptr, nullptr, nullptr, nullptr, nullptr, 0 }
};

// component exports
extern "C"
{

SAL_DLLPUBLIC_EXPORT void * textconversiondlgs_component_getFactory(
    const char * pImplName, void * pServiceManager, void * pRegistryKey )
{
    return ::cppu::component_getFactoryHelper(
        pImplName, pServiceManager, pRegistryKey , g_entries_unodialogs_chinesetranslation );
}
}


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
